#ifndef GRAPHICS_MENU_H
#define GRAPHICS_MENU_H

#include <pglineedit.h>
#include "Menu.h"

class GraphicsMenu : public Menu
{
    MENU_SINGLETON(Graphics);

  public:
    void eventShow();
    void eventHide();

  protected:

    PARAGUI_CALLBACK(onOk);
    PARAGUI_CALLBACK(onCancel);
    PARAGUI_CALLBACK(onFullScreenCheck);
    PARAGUI_CALLBACK(onFullFrameRateCheck);


    bool m_fullScreenEnabled;
    bool m_lastFullScreenEnabled;

    bool m_fullFrameRateEnabled;
    bool m_lastFullFrameRateEnabled;

    bool m_autoPress;
};

#endif // GRAPHICS_MENU
